#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heredoc
version:              0.2.0.0
visibility:           public
id:                   heredoc-0.2.0.0-1fHEYXo5Sno3wcFmeoc81p
key:                  heredoc-0.2.0.0-1fHEYXo5Sno3wcFmeoc81p
license:              LicenseRef-PublicDomain
maintainer:           jameshfisher@gmail.com
author:               James H. Fisher
homepage:             http://hackage.haskell.org/package/heredoc
synopsis:             multi-line string / here document using QuasiQuotes
description:          multi-line string / here document using QuasiQuotes
category:             Text
abi:                  b9448ce58cf8a77cd683debbaa1423fc
exposed:              True
exposed-modules:      Text.Heredoc
import-dirs:          /usr/lib/ghc-8.10.5/site-local/heredoc-0.2.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/heredoc-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/heredoc-0.2.0.0
hs-libraries:         HSheredoc-0.2.0.0-1fHEYXo5Sno3wcFmeoc81p
depends:              base-4.14.2.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-heredoc/html/heredoc.haddock
haddock-html:         /usr/share/doc/haskell-heredoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

